==> filelist_formatter-8.x-1.0.tar.gz: filelist_formatter/src/Plugin/Field/FieldFormatter/FileListFormatter.php <==
<?php

/**
 * @file
 * Contains \Drupal\filelist_formatter\Plugin\field\formatter\FileListFormatter.
 *
 * @author keopx
 */

namespace Drupal\filelist_formatter\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\SafeMarkup;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'filelist_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "filelist_formatter",
 *   module = "filelist_formatter",
 *   label = @Translation("List"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class FileListFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'filelist_formatter_type' => 'ul',
      'filelist_formatter_class' => 'file-list',
    ) + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $settings = $this->getSettings();

    $form['filelist_formatter_type'] = [
      '#title' => t('List type'),
      '#type' => 'select',
      '#options' => [
        'ul' => t('Unordered HTML list (ul)'),
        'ol' => t('Ordered HTML list (ol)'),
      ],
      '#default_value' => $settings['filelist_formatter_type'],
      '#required' => TRUE,
    ];
    $form['filelist_formatter_class'] = [
      '#title' => t('List classes'),
      '#type' => 'textfield',
      '#size' => 40,
      '#description' => t('A CSS class to use in the markup for the field list.'),
      '#default_value' => $settings['filelist_formatter_class'],
      '#required' => FALSE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $settings = $this->getSettings();

    switch ($settings['filelist_formatter_type']) {
      case 'ul':
        $summary[] = t('Unordered HTML list');
        break;

      case 'ol':
        $summary[] = t('Ordered HTML list');
        break;
    }

    if ($settings['filelist_formatter_class']) {
      $summary[] = t('CSS Class') . ': ' . SafeMarkup::checkPlain($settings['filelist_formatter_class']);
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $settings = $this->getSettings();

    if (!$items->isEmpty()) {
      foreach ($items as $delta => $item) {
        if ($item->isDisplayed() && $item->entity) {
          $elements[$delta] = [
            '#theme' => 'file_link',
            '#file' => $item->entity,
            '#description' => $item->description,
          ];
          // Pass field item attributes to the theme function.
          if (isset($item->_attributes)) {
            $elements[$delta] += ['#attributes' => []];
            $elements[$delta]['#attributes'] += $item->_attributes;
            // Unset field item attributes since they have been included in the
            // formatter output and should not be rendered in the field template.
            unset($item->_attributes);
          }
        }
      }
      $classes = explode(' ', $settings['filelist_formatter_class']);

      $elements = [
        '#theme' => 'item_list',
        '#items' => $elements,
        '#list_type' => $settings['filelist_formatter_type'],
        '#attributes' => [
          'class' => $classes,
        ],
      ];
    }

    return $elements;
  }

}

==> filelist_formatter-8.x-1.1.tar.gz: filelist_formatter/src/Plugin/Field/FieldFormatter/FileListFormatter.php <==
<?php

/**
 * @file
 * Contains \Drupal\filelist_formatter\Plugin\field\formatter\FileListFormatter.
 *
 * @author keopx
 */

namespace Drupal\filelist_formatter\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\SafeMarkup;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'filelist_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "filelist_formatter",
 *   module = "filelist_formatter",
 *   label = @Translation("List"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class FileListFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
        'filelist_formatter_type' => 'ul',
        'filelist_formatter_class' => 'file-list',
        'filelist_formatter_filesize' => FALSE,
      ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $settings = $this->getSettings();

    $form['filelist_formatter_type'] = [
      '#title' => t('List type'),
      '#type' => 'select',
      '#options' => [
        'ul' => t('Unordered HTML list (ul)'),
        'ol' => t('Ordered HTML list (ol)'),
      ],
      '#default_value' => $settings['filelist_formatter_type'],
      '#required' => TRUE,
    ];
    $form['filelist_formatter_class'] = [
      '#title' => t('List classes'),
      '#type' => 'textfield',
      '#size' => 40,
      '#description' => t('A CSS class to use in the markup for the field list.'),
      '#default_value' => $settings['filelist_formatter_class'],
      '#required' => FALSE,
    ];
    $form['filelist_formatter_filesize'] = [
      '#title' => t('Show filesize'),
      '#type' => 'checkbox',
      '#description' => t('Display the file size.'),
      '#default_value' => $settings['filelist_formatter_filesize'],
      '#required' => FALSE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $settings = $this->getSettings();

    switch ($settings['filelist_formatter_type']) {
      case 'ul':
        $summary[] = t('Unordered HTML list');
        break;

      case 'ol':
        $summary[] = t('Ordered HTML list');
        break;
    }

    if ($settings['filelist_formatter_class']) {
      $summary[] = t('CSS Class') . ': ' . SafeMarkup::checkPlain($settings['filelist_formatter_class']);
    }
    if ($settings['filelist_formatter_filesize']) {
      $summary[] = t('Show filesize');
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $settings = $this->getSettings();

    if (!$items->isEmpty()) {
      foreach ($items as $delta => $item) {
        if ($item->isDisplayed() && $item->entity) {
          $description = $item->description;
          if ($settings['filelist_formatter_filesize']) {
            $description = $description . ' (' . format_size($item->entity->getSize()) . ')';
          }
          $elements[$delta] = [
            '#theme' => 'file_link',
            '#file' => $item->entity,
            '#description' => $description,
          ];
          // Pass field item attributes to the theme function.
          if (isset($item->_attributes)) {
            $elements[$delta] += ['#attributes' => []];
            $elements[$delta]['#attributes'] += $item->_attributes;
            // Unset field item attributes since they have been included in the
            // formatter output and should not be rendered in the field template.
            unset($item->_attributes);
          }
        }
      }
      $classes = explode(' ', $settings['filelist_formatter_class']);

      $elements = [
        '#theme' => 'item_list',
        '#items' => $elements,
        '#list_type' => $settings['filelist_formatter_type'],
        '#attributes' => [
          'class' => $classes,
        ],
      ];
    }

    return $elements;
  }

}
